@@ -15,6 +15,13 @@ from ckeditor import utils
 THUMBNAIL_SIZE = (75, 75)
 
 
+def image_verify(f):
+    try:
+        Image.open(f).verify()
+    except IOError:
+        raise utils.NotAnImageException
+
+
 def create_thumbnail(file_path):
     thumbnail_filename = utils.get_thumb_filename(file_path)
     thumbnail_format = utils.get_image_format(os.path.splitext(file_path)[1])
